@@ -83,14 +83,14 @@ analyze_knitr_in <- function(expr, results) {
   expr <- ignore_ignore(expr)
   files <- analyze_strings(expr[-1])
   lapply(files, analyze_knitr_file, results = results)
-  ht_set(results$knitr_in, encode_path(files))
+  ht_set(results$knitr_in, reencode_path(files))
 }
 
 analyze_file_in <- function(expr, results) {
   expr <- ignore_ignore(expr)
   x <- analyze_strings(expr[-1])
   x <- file.path(x)
-  x <- encode_path(x)
+  x <- reencode_path(x)
   ht_set(results$file_in, x)
 }
 
@@ -98,7 +98,7 @@ analyze_file_out <- function(expr, results) {
   expr <- ignore_ignore(expr)
   x <- analyze_strings(expr[-1])
   x <- file.path(x)
-  x <- encode_path(x)
+  x <- reencode_path(x)
   ht_set(results$file_out, x)
 }
 
@@ -106,7 +106,7 @@ analyze_knitr_file <- function(file, results) {
   if (!length(file)) {
     return(list())
   }
-  fragments <- safe_get_tangled_frags(file)
+  fragments <- get_tangled_frags(file)
   out <- ignore(analyze_code)(fragments, as_list = FALSE)
   if (length(out)){
     for (slot in knitr_in_slots) {
@@ -118,7 +118,7 @@ analyze_knitr_file <- function(file, results) {
 analyze_namespaced <- function(expr, results, locals, allowed_globals) {
   x <- safe_deparse(expr)
   if (!ht_exists(locals, x)) {
-    ht_set(results$namespaced, encode_namespaced(x))
+    ht_set(results$namespaced, reencode_namespaced(x))
   }
 }
 
@@ -273,21 +273,7 @@ is_callish <- function(x) {
   length(x) > 0 && is.language(x) && (is.call(x) || is.recursive(x))
 }
 
-# From https://github.com/duncantl/CodeDepends/blob/master/R/sweave.R#L15
-get_tangled_frags <- function(doc) {
-  assert_pkg("knitr")
-  id <- make.names(tempfile(), unique = FALSE, allow_ = TRUE)
-  con <- textConnection(id, "w", local = TRUE)
-  on.exit(close(con))
-  with_options(
-    new = list(knitr.purl.inline = TRUE),
-    code = knitr::knit(doc, output = con, tangle = TRUE, quiet = TRUE)
-  )
-  code <- textConnectionValue(con)
-  parse(text = code)
-}
-
-safe_get_tangled_frags <- function(file) {
+get_tangled_frags <- function(file) {
   if (!length(file)) {
     return(character(0))
   }
@@ -300,7 +286,7 @@ safe_get_tangled_frags <- function(file) {
     return(character(0))
   }
   fragments <- tryCatch({
-    get_tangled_frags(file)
+    parse(text = get_tangled_text(file))
   },
   error = function(e) {
     warning(
@@ -312,6 +298,19 @@ safe_get_tangled_frags <- function(file) {
   })
 }
 
+# From https://github.com/duncantl/CodeDepends/blob/master/R/sweave.R#L15
+get_tangled_text <- function(doc) {
+  assert_pkg("knitr")
+  id <- make.names(tempfile(), unique = FALSE, allow_ = TRUE)
+  con <- textConnection(id, "w", local = TRUE)
+  on.exit(close(con))
+  with_options(
+    new = list(knitr.purl.inline = TRUE),
+    code = knitr::knit(doc, output = con, tangle = TRUE, quiet = TRUE)
+  )
+  textConnectionValue(con)
+}
+
 # Functions borrowed directly from codetools to deal with
 # nested replacement functions:
 # https://github.com/cran/codetools/blob/9bac1daaf19a36bd03a2cd7d67041893032e7a04/R/codetools.R#L302-L365 # nolint
