@@ -70,9 +70,9 @@ deps_target <- function(
   config,
   character_only = FALSE
 ) {
-  log_msg("begin deps_target()", target = target, config = config)
+  config$logger$minor("begin deps_target()", target = target)
   on.exit(
-    log_msg("end deps_target()", target = target, config = config),
+    config$logger$minor("end deps_target()", target = target),
     add = TRUE
   )
   if (!character_only) {
@@ -109,7 +109,7 @@ get_deps_knitr <- function(target) {
   }
   out <- new_code_analysis_results()
   if (is_encoded_path(target)) {
-    target <- decode_path(target)
+    target <- redecode_path(target)
   }
   analyze_knitr_file(target, out)
   list_code_analysis_results(out)
@@ -118,11 +118,11 @@ get_deps_knitr <- function(target) {
 decode_deps_list <- function(x) {
   for (field in c("file_in", "file_out", "knitr_in")) {
     if (length(x[[field]])) {
-      x[[field]] <- decode_path(x[[field]])
+      x[[field]] <- redecode_path(x[[field]])
     }
   }
   if (length(x$namespaced)) {
-    x$namespaced <- decode_namespaced(x$namespaced)
+    x$namespaced <- redecode_namespaced(x$namespaced)
   }
   x
 }
@@ -268,7 +268,7 @@ tracked <- function(config) {
     },
     jobs = config$jobs_preprocess
   )
-  display_keys(clean_dependency_list(out), config)
+  config$cache$display_keys(clean_dependency_list(out))
 }
 
 clean_dependency_list <- function(x) {
