@@ -5,7 +5,7 @@ testrun <- function(config) {
       plan = config$plan,
       targets = config$targets,
       envir = config$envir,
-      verbose = config$verbose,
+      verbose = config$logger$verbose,
       parallelism = config$parallelism,
       jobs = config$jobs,
       packages = config$packages,
@@ -27,7 +27,7 @@ testconfig <- function(config) {
     plan = config$plan,
     targets = config$targets,
     envir = config$envir,
-    verbose = config$verbose,
+    verbose = config$logger$verbose,
     parallelism = config$parallelism,
     jobs = config$jobs,
     packages = config$packages,
